@@ -1,9 +1,9 @@
 import os
 
-from .script import ScriptDirectory
-from .runtime.environment import EnvironmentContext
-from . import util
 from . import autogenerate as autogen
+from . import util
+from .runtime.environment import EnvironmentContext
+from .script import ScriptDirectory
 
 
 def list_templates(config):
@@ -15,10 +15,9 @@ def list_templates(config):
 
     config.print_stdout("Available templates:\n")
     for tempname in os.listdir(config.get_template_directory()):
-        with open(os.path.join(
-                config.get_template_directory(),
-                tempname,
-                'README')) as readme:
+        with open(
+            os.path.join(config.get_template_directory(), tempname, "README")
+        ) as readme:
             synopsis = next(readme)
         config.print_stdout("%s - %s", tempname, synopsis)
 
@@ -26,7 +25,7 @@ def list_templates(config):
     config.print_stdout("\n  alembic init --template generic ./scripts")
 
 
-def init(config, directory, template='generic'):
+def init(config, directory, template="generic"):
     """Initialize a new scripts directory.
 
     :param config: a :class:`.Config` object.
@@ -41,48 +40,58 @@ def init(config, directory, template='generic'):
     if os.access(directory, os.F_OK):
         raise util.CommandError("Directory %s already exists" % directory)
 
-    template_dir = os.path.join(config.get_template_directory(),
-                                template)
+    template_dir = os.path.join(config.get_template_directory(), template)
     if not os.access(template_dir, os.F_OK):
         raise util.CommandError("No such template %r" % template)
 
-    util.status("Creating directory %s" % os.path.abspath(directory),
-                os.makedirs, directory)
+    util.status(
+        "Creating directory %s" % os.path.abspath(directory),
+        os.makedirs,
+        directory,
+    )
 
-    versions = os.path.join(directory, 'versions')
-    util.status("Creating directory %s" % os.path.abspath(versions),
-                os.makedirs, versions)
+    versions = os.path.join(directory, "versions")
+    util.status(
+        "Creating directory %s" % os.path.abspath(versions),
+        os.makedirs,
+        versions,
+    )
 
     script = ScriptDirectory(directory)
 
     for file_ in os.listdir(template_dir):
         file_path = os.path.join(template_dir, file_)
-        if file_ == 'alembic.ini.mako':
+        if file_ == "alembic.ini.mako":
             config_file = os.path.abspath(config.config_file_name)
             if os.access(config_file, os.F_OK):
                 util.msg("File %s already exists, skipping" % config_file)
             else:
                 script._generate_template(
-                    file_path,
-                    config_file,
-                    script_location=directory
+                    file_path, config_file, script_location=directory
                 )
         elif os.path.isfile(file_path):
             output_file = os.path.join(directory, file_)
-            script._copy_file(
-                file_path,
-                output_file
-            )
+            script._copy_file(file_path, output_file)
 
-    util.msg("Please edit configuration/connection/logging "
-             "settings in %r before proceeding." % config_file)
+    util.msg(
+        "Please edit configuration/connection/logging "
+        "settings in %r before proceeding." % config_file
+    )
 
 
 def revision(
-        config, message=None, autogenerate=False, sql=False,
-        head="head", splice=False, branch_label=None,
-        version_path=None, rev_id=None, depends_on=None,
-        process_revision_directives=None):
+    config,
+    message=None,
+    autogenerate=False,
+    sql=False,
+    head="head",
+    splice=False,
+    branch_label=None,
+    version_path=None,
+    rev_id=None,
+    depends_on=None,
+    process_revision_directives=None,
+):
     """Create a new revision file.
 
     :param config: a :class:`.Config` object.
@@ -91,7 +100,8 @@ def revision(
      ``-m`` option to ``alembic revision``.
 
     :param autogenerate: whether or not to autogenerate the script from
-     the database; this is the ``--autogenerate`` option to ``alembic revision``.
+     the database; this is the ``--autogenerate`` option to
+     ``alembic revision``.
 
     :param sql: whether to dump the script out as a SQL string; when specified,
      the script is dumped to stdout.  This is the ``--sql`` option to
@@ -134,35 +144,46 @@ def revision(
     command_args = dict(
         message=message,
         autogenerate=autogenerate,
-        sql=sql, head=head, splice=splice, branch_label=branch_label,
-        version_path=version_path, rev_id=rev_id, depends_on=depends_on
+        sql=sql,
+        head=head,
+        splice=splice,
+        branch_label=branch_label,
+        version_path=version_path,
+        rev_id=rev_id,
+        depends_on=depends_on,
     )
     revision_context = autogen.RevisionContext(
-        config, script_directory, command_args,
-        process_revision_directives=process_revision_directives)
-
-    environment = util.asbool(
-        config.get_main_option("revision_environment")
+        config,
+        script_directory,
+        command_args,
+        process_revision_directives=process_revision_directives,
     )
 
+    environment = util.asbool(config.get_main_option("revision_environment"))
+
     if autogenerate:
         environment = True
 
         if sql:
             raise util.CommandError(
-                "Using --sql with --autogenerate does not make any sense")
+                "Using --sql with --autogenerate does not make any sense"
+            )
 
         def retrieve_migrations(rev, context):
             revision_context.run_autogenerate(rev, context)
             return []
+
     elif environment:
+
         def retrieve_migrations(rev, context):
             revision_context.run_no_autogenerate(rev, context)
             return []
+
     elif sql:
         raise util.CommandError(
             "Using --sql with the revision command when "
-            "revision_environment is not configured does not make any sense")
+            "revision_environment is not configured does not make any sense"
+        )
 
     if environment:
         with EnvironmentContext(
@@ -171,14 +192,11 @@ def revision(
             fn=retrieve_migrations,
             as_sql=sql,
             template_args=revision_context.template_args,
-            revision_context=revision_context
+            revision_context=revision_context,
         ):
             script_directory.run_env()
 
-    scripts = [
-        script for script in
-        revision_context.generate_scripts()
-    ]
+    scripts = [script for script in revision_context.generate_scripts()]
     if len(scripts) == 1:
         return scripts[0]
     else:
@@ -207,13 +225,17 @@ def merge(config, revisions, message=None, branch_label=None, rev_id=None):
 
     script = ScriptDirectory.from_config(config)
     template_args = {
-        'config': config  # Let templates use config for
-                          # e.g. multiple databases
+        "config": config  # Let templates use config for
+        # e.g. multiple databases
     }
     return script.generate_revision(
-        rev_id or util.rev_id(), message, refresh=True,
-        head=revisions, branch_labels=branch_label,
-        **template_args)
+        rev_id or util.rev_id(),
+        message,
+        refresh=True,
+        head=revisions,
+        branch_labels=branch_label,
+        **template_args
+    )
 
 
 def upgrade(config, revision, sql=False, tag=None):
@@ -237,7 +259,7 @@ def upgrade(config, revision, sql=False, tag=None):
     if ":" in revision:
         if not sql:
             raise util.CommandError("Range revision not allowed")
-        starting_rev, revision = revision.split(':', 2)
+        starting_rev, revision = revision.split(":", 2)
 
     def upgrade(rev, context):
         return script._upgrade_revs(revision, rev)
@@ -249,7 +271,7 @@ def upgrade(config, revision, sql=False, tag=None):
         as_sql=sql,
         starting_rev=starting_rev,
         destination_rev=revision,
-        tag=tag
+        tag=tag,
     ):
         script.run_env()
 
@@ -274,10 +296,11 @@ def downgrade(config, revision, sql=False, tag=None):
     if ":" in revision:
         if not sql:
             raise util.CommandError("Range revision not allowed")
-        starting_rev, revision = revision.split(':', 2)
+        starting_rev, revision = revision.split(":", 2)
     elif sql:
         raise util.CommandError(
-            "downgrade with --sql requires <fromrev>:<torev>")
+            "downgrade with --sql requires <fromrev>:<torev>"
+        )
 
     def downgrade(rev, context):
         return script._downgrade_revs(revision, rev)
@@ -289,7 +312,7 @@ def downgrade(config, revision, sql=False, tag=None):
         as_sql=sql,
         starting_rev=starting_rev,
         destination_rev=revision,
-        tag=tag
+        tag=tag,
     ):
         script.run_env()
 
@@ -306,15 +329,13 @@ def show(config, rev):
     script = ScriptDirectory.from_config(config)
 
     if rev == "current":
+
         def show_current(rev, context):
             for sc in script.get_revisions(rev):
                 config.print_stdout(sc.log_entry)
             return []
-        with EnvironmentContext(
-            config,
-            script,
-            fn=show_current
-        ):
+
+        with EnvironmentContext(config, script, fn=show_current):
             script.run_env()
     else:
         for sc in script.get_revisions(rev):
@@ -340,44 +361,45 @@ def history(config, rev_range=None, verbose=False, indicate_current=False):
     if rev_range is not None:
         if ":" not in rev_range:
             raise util.CommandError(
-                "History range requires [start]:[end], "
-                "[start]:, or :[end]")
+                "History range requires [start]:[end], " "[start]:, or :[end]"
+            )
         base, head = rev_range.strip().split(":")
     else:
         base = head = None
 
-    environment = util.asbool(
-        config.get_main_option("revision_environment")
-    ) or indicate_current
+    environment = (
+        util.asbool(config.get_main_option("revision_environment"))
+        or indicate_current
+    )
 
     def _display_history(config, script, base, head, currents=()):
         for sc in script.walk_revisions(
-                base=base or "base",
-                head=head or "heads"):
+            base=base or "base", head=head or "heads"
+        ):
 
             if indicate_current:
                 sc._db_current_indicator = sc.revision in currents
 
             config.print_stdout(
                 sc.cmd_format(
-                    verbose=verbose, include_branches=True,
-                    include_doc=True, include_parents=True))
+                    verbose=verbose,
+                    include_branches=True,
+                    include_doc=True,
+                    include_parents=True,
+                )
+            )
 
     def _display_history_w_current(config, script, base, head):
         def _display_current_history(rev, context):
-            if head == 'current':
+            if head == "current":
                 _display_history(config, script, base, rev, rev)
-            elif base == 'current':
+            elif base == "current":
                 _display_history(config, script, rev, head, rev)
             else:
                 _display_history(config, script, base, head, rev)
             return []
 
-        with EnvironmentContext(
-            config,
-            script,
-            fn=_display_current_history
-        ):
+        with EnvironmentContext(config, script, fn=_display_current_history):
             script.run_env()
 
     if base == "current" or head == "current" or environment:
@@ -406,7 +428,9 @@ def heads(config, verbose=False, resolve_dependencies=False):
     for rev in heads:
         config.print_stdout(
             rev.cmd_format(
-                verbose, include_branches=True, tree_indicators=False))
+                verbose, include_branches=True, tree_indicators=False
+            )
+        )
 
 
 def branches(config, verbose=False):
@@ -424,13 +448,17 @@ def branches(config, verbose=False):
                 "%s\n%s\n",
                 sc.cmd_format(verbose, include_branches=True),
                 "\n".join(
-                    "%s -> %s" % (
+                    "%s -> %s"
+                    % (
                         " " * len(str(sc.revision)),
                         rev_obj.cmd_format(
-                            False, include_branches=True, include_doc=verbose)
-                    ) for rev_obj in
-                    (script.get_revision(rev) for rev in sc.nextrev)
-                )
+                            False, include_branches=True, include_doc=verbose
+                        ),
+                    )
+                    for rev_obj in (
+                        script.get_revision(rev) for rev in sc.nextrev
+                    )
+                ),
             )
 
 
@@ -454,18 +482,14 @@ def current(config, verbose=False, head_only=False):
         if verbose:
             config.print_stdout(
                 "Current revision(s) for %s:",
-                util.obfuscate_url_pw(context.connection.engine.url)
+                util.obfuscate_url_pw(context.connection.engine.url),
             )
         for rev in script.get_all_current(rev):
             config.print_stdout(rev.cmd_format(verbose))
 
         return []
 
-    with EnvironmentContext(
-        config,
-        script,
-        fn=display_version
-    ):
+    with EnvironmentContext(config, script, fn=display_version):
         script.run_env()
 
 
@@ -491,7 +515,7 @@ def stamp(config, revision, sql=False, tag=None):
     if ":" in revision:
         if not sql:
             raise util.CommandError("Range revision not allowed")
-        starting_rev, revision = revision.split(':', 2)
+        starting_rev, revision = revision.split(":", 2)
 
     def do_stamp(rev, context):
         return script._stamp_revs(revision, rev)
@@ -503,7 +527,7 @@ def stamp(config, revision, sql=False, tag=None):
         as_sql=sql,
         destination_rev=revision,
         starting_rev=starting_rev,
-        tag=tag
+        tag=tag,
     ):
         script.run_env()
 
@@ -520,23 +544,21 @@ def edit(config, rev):
     script = ScriptDirectory.from_config(config)
 
     if rev == "current":
+
         def edit_current(rev, context):
             if not rev:
                 raise util.CommandError("No current revisions")
             for sc in script.get_revisions(rev):
                 util.edit(sc.path)
             return []
-        with EnvironmentContext(
-            config,
-            script,
-            fn=edit_current
-        ):
+
+        with EnvironmentContext(config, script, fn=edit_current):
             script.run_env()
     else:
         revs = script.get_revisions(rev)
         if not revs:
             raise util.CommandError(
-                "No revision files indicated by symbol '%s'" % rev)
+                "No revision files indicated by symbol '%s'" % rev
+            )
         for sc in revs:
             util.edit(sc.path)
-
