@@ -10,18 +10,20 @@
 
 from __future__ import absolute_import
 
-import warnings
-from sqlalchemy import exc as sa_exc
 import re
+import warnings
+
+from sqlalchemy import exc as sa_exc
 
 
 def setup_filters():
     """Set global warning behavior for the test suite."""
-    warnings.filterwarnings('ignore',
-                            category=sa_exc.SAPendingDeprecationWarning)
-    warnings.filterwarnings('error', category=sa_exc.SADeprecationWarning)
-    warnings.filterwarnings('error', category=sa_exc.SAWarning)
-    warnings.filterwarnings('error', category=DeprecationWarning)
+    warnings.filterwarnings(
+        "ignore", category=sa_exc.SAPendingDeprecationWarning
+    )
+    warnings.filterwarnings("error", category=sa_exc.SADeprecationWarning)
+    warnings.filterwarnings("error", category=sa_exc.SAWarning)
+    warnings.filterwarnings("error", category=DeprecationWarning)
 
 
 def assert_warnings(fn, warning_msgs, regex=False):
